PCB Environment: Data Fields - Functions

PCB Environment 2

Loading...
Searching...
No Matches
Here is a list of all functions with links to the structures/unions they belong to:

### - g -

- gather() : DSNParserBase
- gatherArray() : DSNParserBase
- gatherConnections() : Component
- get() : Logger, UserSettings
- get45DegreeStepsBetween() : GridDirection
- get_state() : Agent, Env, EnvPCB, RRRAgent, UserAgent
- getAction() : ActionSpace
- getActionTab() : Window
- getActiveAreaBbox() : PCBoard
- getActiveConnections() : UIActions
- getActiveLayer() : UIActions
- getAddressOffset() : NavGrid
- getApplication() : Window
- getAStarCosts() : NavGrid
- getAutoAgent() : UIApplication
- getBackDirection() : NavPoint
- getBackEdge() : NavPoint
- getBbox() : Camera, Object, UniformGrid25
- getBoard() : Net
- getBox() : UniformGrid25
- getBVH() : PCBoard
- getCenter() : Object
- getCenter25() : Object
- getChildAt() : Object
- getChildren() : Object
- getCircle() : Via
- getClearance() : Object
- getColor() : Connection, NavTri, Net
- getComponent() : PCBoard
- getComponentAreaBbox() : PCBoard
- getComponentAt() : PCBoard
- getComponents() : PCBoard
- getConnection() : DRCViolation, PCBoard, UIActions
- getConnectionBetween() : Net
- getConnectionLRU() : Agent
- getConnections() : Agent
- getConnectionSet() : Agent
- getConnectionsPy() : Net
- getCornerMax() : Camera
- getCornerMin() : Camera
- getCost() : NavPoint
- getCosts() : NavGrid
- getData() : PCBFactory
- getDims() : Camera
- getDirection() : Segment_25
- getDirectionStride() : NavGrid
- getEdge() : NavPoint
- getEndsPy() : Connection
- getEnum() : Parameter
- getEpsilon() : Policy
- getExpansionForTracks() : NavSpacings
- getExpansionForVias() : NavSpacings
- getFaceGraphPy() : NavTriangulation
- getFillColor() : Component
- getFlags() : NavPoint
- getFloat4() : Color
- getFloatMVP() : Camera
- getFullName() : Object
- getGLWidget() : Window
- getGranularity() : StepLock
- getHalfWidthSpan() : WideSegment_25
- getIllegal() : ActionSpace
- getInstance() : GLWidget, Shaders
- getIntegerPointsPy() : Path
- getIteration() : Agent
- getKOCounts() : NavPoint
- getLastRouteMode() : UIActions
- getLayer() : ActionTab, LayerAlphaSlider, NavPoint, PCBoard
- getLayerAlpha() : RatsNest
- getLayerForSide() : PCBoard
- getLayerMask() : Connection, Net
- getLayerMCoverage() : NavImage< chan_t >
- getLayers() : PCBoard
- getLayersPy() : PCBoard
- getLayoutArea() : PCBoard
- getLayoutAreaMaxMargin() : PCBFactory
- getLayoutAreaMinMargin() : PCBFactory
- getLikelySignalTypeForName() : Net
- getLineColor() : Component
- getLineGraphPy() : NavTriangulation
- getLoadFanout() : PCBFactory
- getLoadTracksForNet() : PCBFactory
- getLocation() : DRCViolation
- getLock() : PCBoard
- getMinClearance() : Net
- getMinClearanceNets() : PCBoard
- getMinClearancePins() : PCBoard
- getMinTrackWidth() : Net, PCBoard
- getMinViaDiameter() : PCBoard
- getMVP() : Camera
- getNavGrid() : PCBoard
- getNavIdx() : NavTriangulation
- getNavTri() : NavTriangulation
- getNavTris() : NavTriangulation
- getNet() : PCBoard
- getNetOverrides() : PCBFactory
- getNets() : PCBoard
- getNumber() : Layer
- getNumComponents() : PCBoard
- getNumLayers() : PCBoard
- getNumNets() : PCBoard
- getNumPoints() : NavGrid
- getNumPoints2D() : UniformGrid25
- getNumPoints3D() : UniformGrid25
- getOrigin() : Camera
- getParameters() : Agent
- getParameterTab() : Window
- getParent() : Object, Pin
- getPath() : LogFile, Track
- getPathCoordinatesNumpy() : NavGrid
- getPathNumpy() : Track
- getPathPy() : Track
- getPCB() : Agent, GLWidget, NavGrid, UIApplication
- getPerpendicularCCW() : Segment_25
- getPin() : Component, PCBoard
- getPins() : Component, Net
- getPinsPy() : Net
- getPoint() : NavGrid, NavPointRef, Path
- getPointFromAddressOffset() : NavGrid
- getPoints() : NavGrid, Path
- getPointsNumpy() : Path
- getPolicy() : Agent
- getProgress() : Agent
- getPy() : Action, ActionSpace, AShape, CircleEx, Component, Connection, DRCViolation, IsoRectEx, Layer, NavGrid, Net, Object, PCBoard, Pin, PolygonEx, ResultCollection, ResultRecord, RouterResult, StateRepresentation, Track, TriangleEx, Via, WideSegment_25
- getRanges() : RecordRangesROP
- getRatsNest() : Connection
- getRectifySegmentsRadians() : PCBFactory
- getRef() : py::ObjectRef
- getRefPoint() : Component, NavPoint
- getRefPoint25() : NavPoint
- getRewardFn() : Agent
- getRouteMode() : UIActions
- getRoutePreview() : UIActions
- getScore() : NavPoint
- getSearchSeq() : NavGrid, NavTriangulation
- getSegment() : Track
- getSegmentAt() : Path
- getSegments() : Track
- getSegmentsNumpy() : Track
- getSegmentsPy() : Track
- getSegmentTo() : NavPoint
- getSelectionLayer() : UIActions
- getSelectionSetC() : UIActions
- getSelectionSetP() : UIActions
- getSelectionType() : UIActions
- getShape() : Object
- getShortPy() : Via, WideSegment_25
- getSingleLayer() : Object
- getSize() : UniformGrid25
- getSlider() : LayerAlphaSlider
- getSourceFilePath() : PCBoard
- getSpacings() : NavGrid
- getSR() : Agent
- getStartLayerFor() : Pin
- getStepLock() : Agent
- getTemperature() : Policy
- getTimeoutMS() : ActionTab
- getTNG() : PCBoard
- getTopology() : PCBFactory
- getTrack() : Connection
- getTrackAt() : Connection
- getTracks() : Connection
- getTracksPy() : Connection
- getTriangle() : NavTri
- getType() : Layer
- getUBO() : Camera
- getUndo() : Action
- getUnitLength_nm() : PCBFactory
- getUserAgent() : UIApplication
- getVia() : Track
- getViaDiameter() : Net
- getViaHeight() : Net
- getVias() : Track
- getViasNumpy() : Track
- getViasPy() : Track
- getViaStartLayer() : Net
- getVisits() : NavPoint
- getWriteSeq() : NavPoint
- getZoom() : Camera
- GIL_guard() : py::GIL_guard
- GridDirection() : GridDirection
- grow() : PolygonEx
- grown() : CircleEx, PolygonEx, WideSegment_25